pub struct EditMessageReplyMarkup {
pub chat_id: Recipient,
pub message_id: MessageId,
pub business_connection_id: Option<BusinessConnectionId>,
pub reply_markup: Option<InlineKeyboardMarkup>,
}Expand description
Use this method to edit only the reply markup of messages. On success, the edited Message is returned. Note that business messages that were not sent by the bot and do not contain an inline keyboard can only be edited within 48 hours from the time they were sent.
See also: EditMessageMediaInline
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername).
message_id: MessageIdIdentifier of the message to edit
business_connection_id: Option<BusinessConnectionId>Unique identifier of the business connection on behalf of which the message to be edited was sent
reply_markup: Option<InlineKeyboardMarkup>A JSON-serialized object for an inline keyboard.
Implementations