pub struct RestrictChatMember {
pub chat_id: Recipient,
pub user_id: UserId,
pub permissions: ChatPermissions,
pub use_independent_chat_permissions: Option<bool>,
pub until_date: Option<DateTime<Utc>>,
}Expand description
Use this method to restrict a user in a supergroup. The bot must be an administrator in the supergroup for this to work and must have the appropriate admin rights. Pass True for all permissions to lift restrictions from a user. Returns True on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
user_id: UserIdUnique identifier of the target user
permissions: ChatPermissionsA JSON-serialized object for new user permissions
use_independent_chat_permissions: Option<bool>Pass True if chat permissions are set independently. Otherwise, the can_send_other_messages and can_add_web_page_previews permissions will imply the can_send_messages, can_send_audios, can_send_documents, can_send_photos, can_send_videos, can_send_video_notes, and can_send_voice_notes permissions; the can_send_polls permission will imply the can_send_messages permission.
until_date: Option<DateTime<Utc>>Date when the user will be unbanned, unix time. If user is banned for more than 366 days or less than 30 seconds from the current time they are considered to be banned forever
Implementations
Sourceimpl RestrictChatMember
impl RestrictChatMember
pub fn new( chat_id: impl Into<Recipient>, user_id: UserId, permissions: ChatPermissions, ) -> RestrictChatMember ⓘ