Struct SetMyDescription

pub struct SetMyDescription {
    pub description: Option<String>,
    pub language_code: Option<String>,
}
Use this method to change the bot’s description, which is shown in the chat with the bot if the chat is empty. Returns True on success.

Fields

description: Option<String>

New bot description; 0-512 characters. Pass an empty string to remove the dedicated description for the given language.

language_code: Option<String>

A two-letter ISO 639-1 language code. If empty, the description will be applied to all users for whose language there is no dedicated description.

Implementations