pub enum UniqueGiftOrigin {
Upgrade,
Transfer,
Resale,
}Expand description
Origin of the gift. Currently, either Upgrade for gifts upgraded from
regular gifts, Transfer for gifts transferred from other users or
channels, or Resale for gifts bought from other users
Variants