pub struct Gift {
pub id: GiftId,
pub sticker: Sticker,
pub star_count: u32,
pub upgrade_star_count: Option<u32>,
pub total_count: Option<u32>,
pub remaining_count: Option<u32>,
}Expand description
This object represents a gift that can be sent by the bot.
Fields
id: GiftIdUnique identifier of the gift
sticker: StickerThe sticker that represents the gift
star_count: u32The number of Telegram Stars that must be paid to send the sticker
upgrade_star_count: Option<u32>The number of Telegram Stars that must be paid to upgrade the gift to a unique one
total_count: Option<u32>The total number of the gifts of this type that can be sent; for limited gifts only
remaining_count: Option<u32>The number of remaining gifts of this type that can be sent; for limited gifts only
Implementations
Sourceimpl Gift
impl Gift
pub fn is_limited(&self) -> bool
Sourcepub fn limited_count(&self) -> Option<(u32, u32)>
pub fn limited_count(&self) -> Option<(u32, u32)>
Returns None if Gift isn’t limited or a tuple where first element is
Self::remaining_count and second is Self::total_count