pub struct OwnedGiftRegular {
pub gift: Gift,
pub owned_gift_id: Option<OwnedGiftId>,
pub sender_user: Option<User>,
pub send_date: DateTime<Utc>,
pub text: Option<String>,
pub entities: Option<Vec<MessageEntity>>,
pub is_private: bool,
pub is_saved: bool,
pub can_be_upgraded: bool,
pub was_refunded: bool,
pub convert_star_count: Option<u32>,
pub prepaid_upgrade_star_count: Option<u32>,
}Expand description
Describes a regular gift owned by a user or a chat.
Fields
gift: GiftInformation about the regular gift
owned_gift_id: Option<OwnedGiftId>Unique identifier of the gift for the bot; for gifts received on behalf of business accounts only
sender_user: Option<User>Sender of the gift if it is a known user
send_date: DateTime<Utc>Date the gift was sent in Unix time
text: Option<String>Text of the message that was added to the gift
entities: Option<Vec<MessageEntity>>Special entities that appear in the text
is_private: booltrue, if the sender and gift text are shown only to the gift receiver;
otherwise, everyone will be able to see them
is_saved: booltrue, if the gift is displayed on the account’s profile page; for
gifts received on behalf of business accounts only
can_be_upgraded: booltrue, if the gift can be upgraded to a unique gift; for gifts received
on behalf of business accounts only
was_refunded: booltrue, if the gift was refunded and isn’t available anymore
convert_star_count: Option<u32>Number of Telegram Stars that can be claimed by the receiver instead of the gift; omitted if the gift cannot be converted to Telegram Stars
prepaid_upgrade_star_count: Option<u32>Number of Telegram Stars that were paid by the sender for the ability to upgrade the gift