pub struct OwnedGifts {
pub total_count: u32,
pub gifts: Vec<OwnedGift>,
pub next_offset: Option<String>,
}Expand description
Contains the list of gifts received and owned by a user or a chat.
Fields
total_count: u32The total number of gifts owned by the user or the chat
gifts: Vec<OwnedGift>The list of gifts
next_offset: Option<String>Offset for the next request. If empty, then there are no more results