pub struct Poll {Show 13 fields
pub id: String,
pub question: String,
pub options: Vec<PollOption, Global>,
pub is_closed: bool,
pub total_voter_count: i32,
pub is_anonymous: bool,
pub poll_type: PollType,
pub allows_multiple_answers: bool,
pub correct_option_id: Option<u8>,
pub explanation: Option<String>,
pub explanation_entities: Option<Vec<MessageEntity, Global>>,
pub open_period: Option<u16>,
pub close_date: Option<DateTime<Utc>>,
}Expand description
This object contains information about a poll.
Fields
id: StringUnique poll identifier.
question: StringPoll question, 1-255 characters.
options: Vec<PollOption, Global>List of poll options.
is_closed: booltrue, if the poll is closed.
total_voter_count: i32Total number of users that voted in the poll
is_anonymous: boolTrue, if the poll is anonymous
poll_type: PollTypePoll type, currently can be “regular” or “quiz”
allows_multiple_answers: boolTrue, if the poll allows multiple answers
correct_option_id: Option<u8>0-based identifier of the correct answer option. Available only for polls in the quiz mode, which are closed, or was sent (not forwarded) by the bot or to the private chat with the bot.
explanation: Option<String>Text that is shown when a user chooses an incorrect answer or taps on the lamp icon in a quiz-style poll, 0-200 characters.
explanation_entities: Option<Vec<MessageEntity, Global>>Special entities like usernames, URLs, bot commands, etc. that appear in the explanation.
open_period: Option<u16>Amount of time in seconds the poll will be active after creation.
close_date: Option<DateTime<Utc>>Point in time when the poll will be automatically closed.